==> commons-utils-2.1.0-sources.jar: org/seppiko/commons/utils/ObjectUtil.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * Object Util
 *
 * @author Leonard Woo
 */
public class ObjectUtil {

  /**
   * return object with default
   *
   * @param t object
   * @param defaultValue default value
   * @param <T> object type
   * @return object result, if t is null this is default value
   */
  public static <T> T safeNull(T t, T defaultValue) {
    return isNull(t)? defaultValue: t;
  }

  /**
   * test object is array
   *
   * @param obj object
   * @param <T> object type
   * @return true is not null and it's array object
   */
  public static <T> boolean isArray(T obj) {
    return notNull(obj) && obj.getClass().isArray();
  }

  /**
   * test object array is empty
   *
   * @param array object array
   * @param <T> object type
   * @return true is null or empty
   */
  public static <T> boolean isEmpty(T[] array) {
    return (isNull(array) || array.length == 0);
  }

  /**
   * test object is null
   *
   * @param obj object
   * @param <T> object type
   * @return true is null
   */
  public static <T> boolean isNull(T obj) {
    return null == obj;
  }

  /**
   * test object array is null
   *
   * @param obj object array
   * @param <T> object type
   * @return true is null
   */
  public static <T> boolean isNull(T[] obj) {
    return null == obj;
  }

  /**
   * test object is not null
   *
   * @param obj object
   * @param <T> object type
   * @return true is not null
   */
  public static <T> boolean notNull(T obj) {
    return obj != null;
  }

  /**
   * test object array is not null
   *
   * @param obj object array
   * @param <T> object type
   * @return true is not null
   */
  public static <T> boolean notNull(T[] obj) {
    return null != obj;
  }

  /**
   * Deep copy
   *
   * @param obj source object
   * @return copy object
   * @throws IOException copy failed
   * @throws ClassNotFoundException can not found new object
   */
  public static Object deepCopy(Object obj) throws IOException, ClassNotFoundException {
    ByteArrayOutputStream baos = new ByteArrayOutputStream();
    ObjectOutputStream oos = new ObjectOutputStream(baos);
    oos.writeObject(obj);
    ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
    ObjectInputStream ois = new ObjectInputStream(bais);
    return ois.readObject();
  }

}

==> commons-utils-2.4.0-sources.jar: org/seppiko/commons/utils/ObjectUtil.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * Object Util
 *
 * @author Leonard Woo
 */
public class ObjectUtil {

  /**
   * return object with default
   *
   * @param t object
   * @param defaultValue default value
   * @param <T> object type
   * @return object result, if t is null this is default value
   */
  public static <T> T safeNull(T t, T defaultValue) {
    return isNull(t)? defaultValue: t;
  }

  /**
   * test object is array
   *
   * @param obj object
   * @param <T> object type
   * @return true is not null and it's array object
   */
  public static <T> boolean isArray(T obj) {
    return notNull(obj) && obj.getClass().isArray();
  }

  /**
   * test object array is empty
   *
   * @param array object array
   * @param <T> object type
   * @return true is null or empty
   */
  public static <T> boolean isEmpty(T[] array) {
    return (isNull(array) || array.length == 0);
  }

  /**
   * test object is null
   *
   * @param obj object
   * @param <T> object type
   * @return true is null
   */
  public static <T> boolean isNull(T obj) {
    return null == obj;
  }

  /**
   * test object array is null
   *
   * @param obj object array
   * @param <T> object type
   * @return true is null
   */
  public static <T> boolean isNull(T[] obj) {
    return null == obj;
  }

  /**
   * test object is not null
   *
   * @param obj object
   * @param <T> object type
   * @return true is not null
   */
  public static <T> boolean notNull(T obj) {
    return obj != null;
  }

  /**
   * test object array is not null
   *
   * @param obj object array
   * @param <T> object type
   * @return true is not null
   */
  public static <T> boolean notNull(T[] obj) {
    return null != obj;
  }

  /**
   * Deep copy
   *
   * @param obj source object
   * @return copy object
   * @throws IOException copy failed
   * @throws ClassNotFoundException can not found new object
   */
  public static Object deepCopy(Object obj) throws IOException, ClassNotFoundException {
    ByteArrayOutputStream baos = new ByteArrayOutputStream();
    ObjectOutputStream oos = new ObjectOutputStream(baos);
    oos.writeObject(obj);
    oos.flush();
    ObjectInputStream ois = new ObjectInputStream(new ByteArrayInputStream(baos.toByteArray()));
    Object targetObj = ois.readObject();
    oos.close();
    baos.close();
    ois.close();
    return targetObj;
  }

}
